References
===================

The following is a non-comprehensive list of works used in the development of mpmath
or cited for examples or mathematical definitions used in this documentation.
References not listed here can be found in the source code.

.. [AbramowitzStegun] M Abramowitz & I Stegun. *Handbook of Mathematical Functions, 9th Ed.*, Tenth Printing, December 1972, with corrections (electronic copy: http://people.math.sfu.ca/~cbm/aands/)

.. [Abate] Abate, J., P. Valko (2004). Multi-precision Laplace transform inversion. *International Journal for Numerical Methods in Engineering* 60:979-993, http://dx.doi.org/10.1002/nme.995

.. [Ainsworth] O. R. Ainsworth & L. W. Howell, "An integral representation of the generalized Euler-Mascheroni constants", NASA Technical Paper 2456 (1985), http://ntrs.nasa.gov/archive/nasa/casi.ntrs.nasa.gov/19850014994_1985014994.pdf

.. [Bailey] D H Bailey. "Tanh-Sinh High-Precision Quadrature", http://crd.lbl.gov/~dhbailey/dhbpapers/dhb-tanh-sinh.pdf

.. [Bellman] Bellman, R., R.E. Kalaba, J.A. Lockett (1966). *Numerical inversion of the Laplace transform: Applications to Biology, Economics, Engineering, and Physics*. Elsevier.

.. [BenderOrszag] C M Bender & S A Orszag. *Advanced Mathematical Methods for
    Scientists and Engineers*, Springer 1999

.. [Bernoulli] The Bernoulli Number Page: http://www.bernoulli.org/

.. [BorweinBailey] J Borwein, D H Bailey & R Girgensohn. *Experimentation in Mathematics - Computational Paths to Discovery*, A K Peters, 2003

.. [BorweinBorwein] J Borwein & P B Borwein. *Pi and the AGM: A Study in Analytic Number Theory and Computational Complexity*, Wiley 1987

.. [BorweinTanhSinh] Borwein, Jonathan Michael and Lingyun Ye. “Quadratic Convergence of the Tanh-sinh Quadrature Rule.” (2006). https://web.archive.org/web/20080221230631/http://users.cs.dal.ca/~jborwein/tanh-sinh.pdf

.. [BorweinZeta] P Borwein. "An Efficient Algorithm for the Riemann Zeta Function", http://www.cecm.sfu.ca/personal/pborwein/PAPERS/P155.pdf

.. [Brent79] R. P. Brent, On the Zeros of the Riemann Zeta Function in the Critical Strip, Math. Comp. 33 (1979) 1361--1372

.. [Brent86] R. P. Brent, J. van de Lune, H. J. J. te Riele, D. T. Winter, 'On the Zeros of the Riemann Zeta Function in the Critical Strip. II', Math. Comp. 39 (1982) 681--688.

.. [Buhring] Wolfgang Buhring, "Generalized Hypergeometric Functions at Unit Argument", Proc. Amer. Math. Soc., Vol. 114, No. 1 (Jan. 1992),   pp.145-153

.. [CabralRosetti] L G Cabral-Rosetti & M A Sanchis-Lozano. "Appell Functions and the Scalar One-Loop Three-point Integrals in Feynman Diagrams". http://arxiv.org/abs/hep-ph/0206081

.. [Carlson] B C Carlson. "Numerical computation of real or complex elliptic integrals". http://arxiv.org/abs/math/9409227v1

.. [Coffey] M. W. Coffey, "The Stieltjes constants, their relation to the `\eta_j` coefficients, and representation of the Hurwitz zeta function", 	arXiv:0706.0343v1 http://arxiv.org/abs/0706.0343

.. [Cohen] Cohen, A.M. (2007). Numerical Methods for Laplace Transform  Inversion, Springer.

.. [Corless] R M Corless et al. "On the Lambert W function", Adv. Comp. Math. 5 (1996) 329-359. http://www.apmaths.uwo.ca/~djeffrey/Offprints/W-adv-cm.pdf

.. [Crandall] Richard Crandall, "Note on fast polylogarithm computation" http://www.reed.edu/physics/faculty/crandall/papers/Polylog.pdf

.. [Davies] Davies, B. (2005). *Integral Transforms and their Applications*, Third Edition. Springer.

.. [Davies79] Davies, B., B. Martin (1979). Numerical inversion of the Laplace transform: a survey and comparison of methods. *Journal of Computational Physics* 33:1-32, http://dx.doi.org/10.1016/0021-9991(79)90025-1

.. [Duffy93] Duffy, D.G. (1993). On the numerical inversion of Laplace transforms: Comparison of three new methods on characteristic problems from applications. *ACM Transactions on Mathematical Software* 19(3):333-359, http://dx.doi.org/10.1145/155743.155788

.. [Duffy98] Duffy, D.G. (1998). Advanced Engineering Mathematics, CRC Press.

.. [DLMF] NIST Digital Library of Mathematical Functions. http://dlmf.nist.gov/

.. [Froberg] Carl-Erik Froberg, "On the prime zeta function", BIT 8 (1968), pp. 187-202.

.. [Glasserman] P. Glasserman, J. Ruiz-Mata (2006). Computing the credit loss distribution in the Gaussian copula model: a comparison of methods.  *Journal of Credit Risk* 2(4):33-66, 10.21314/JCR.2006.057

.. [Golub] golub, "some modified matrix eigenvalue problems", siam review 15, p. 318-334 (1973)

.. [GolubWelsch] golub and welsch, "calculations of gaussian quadrature rules", mathematics of computation 23, p. 221-230 (1969)

.. [Gourdon] Xavier Gourdon & Pascal Sebah, The Euler constant: gamma http://numbers.computation.free.fr/Constants/Gamma/gamma.pdf

.. [GradshteynRyzhik] I S Gradshteyn & I M Ryzhik, A Jeffrey & D Zwillinger (eds.), *Table of Integrals, Series and Products*, Seventh edition (2007), Elsevier

.. [GravesMorris] P R Graves-Morris, D E Roberts & A Salam. "The epsilon algorithm and related topics", *Journal of Computational and Applied Mathematics*, Volume 122, Issue 1-2  (October 2000)

.. [Homeier] H.H.H. Homeier - "Scalar Levin-Type Sequence Transformations" arXiv:math/0005209

.. [Hoog] de Hoog, F., J. Knight, A. Stokes (1982). An improved method for numerical inversion of Laplace transforms. *SIAM Journal of Scientific and Statistical Computing* 3:357-366, http://dx.doi.org/10.1137/0903022

.. [Kresser] Numerical Methods for General and Structured Eigenvalue Problems

.. [Kuhlman] Kuhlman, K.L., (2013). Review of Inverse Laplace Transform Algorithms for Laplace-Space Numerical Approaches, *Numerical Algorithms*, 63(2):339-355. http://dx.doi.org/10.1007/s11075-012-9625-3

.. [Lune84] J. van de Lune, 'Sums of Equal Powers of Positive Integers', Dissertation, Vrije Universiteit te Amsterdam, Centrum voor Wiskunde en Informatica, Amsterdam, 1984.

.. [Lune86] J. van de Lune, H. J. J. te Riele, 'On the Zeros of the Riemann Zeta Function in the Critical Strip. III', Math. Comp. 41 (1983) 759--767.

.. [MPFR] The MPFR team. "The MPFR Library: Algorithms and Proofs", http://www.mpfr.org/algorithms.pdf

.. [Michel] N. Michel, "Precise Coulomb wave functions for a wide range of complex `l`, `\eta` and `z`", http://arxiv.org/abs/physics/0702051v1

.. [OEIS] The On-Line Encyclopedia of Integer Sequences (OEIS).

.. [Sidi] A. Sidi - "Pratical Extrapolation Methods"

.. [Slater] L J Slater. *Generalized Hypergeometric Functions*. Cambridge University Press, 1966

.. [Spouge] J L Spouge. "Computation of the gamma, digamma, and trigamma functions", SIAM J. Numer. Anal. Vol. 31, No. 3, pp. 931-944, June 1994.

.. [SrivastavaKarlsson] H M Srivastava & P W Karlsson. *Multiple Gaussian Hypergeometric Series*. Ellis Horwood, 1985.

.. [Stehfest] Stehfest, H. (1970). Algorithm 368: numerical inversion of Laplace transforms. *Communications of the ACM* 13(1):47-49, http://dx.doi.org/10.1145/361953.361969

.. [Stoer] Stoer, Bulirsch - Introduction to Numerical Analysis.

.. [Stroud] stroud and secrest, "gaussian quadrature formulas", prentice-hall (1966)

.. [Talbot] Talbot, A. (1979). The accurate numerical inversion of Laplace transforms. *IMA Journal of Applied Mathematics* 23(1):97, http://dx.doi.org/10.1093/imamat/23.1.97

.. [Thompson] I.J. Thompson & A.R. Barnett, "Coulomb and Bessel Functions of Complex Arguments and Order", J. Comp. Phys., vol 64, no. 2, June 1986.

.. [Trudgian] T. Trudgian, Improvements to Turing Method, Math. Comp.

.. [Vidunas] R Vidunas. "Identities between Appell's and hypergeometric functions". http://arxiv.org/abs/0804.0655

.. [Voros2003] A. Voros, Zeta functions for the Riemann zeros, Ann. Institute Fourier, 53, (2003) 665--699.

.. [Voros2009] A. Voros, Zeta functions over Zeros of Zeta Functions, Lecture Notes of the Unione Matematica Italiana, Springer, 2009.

.. [Weisstein] E W Weisstein. *MathWorld*. http://mathworld.wolfram.com/

.. [Weniger] E.J. Weniger - "Nonlinear Sequence Transformations for the Acceleration of Convergence and the Summation of Divergent Series" arXiv:math/0306302

.. [WhittakerWatson] E T Whittaker & G N Watson. *A Course of Modern Analysis*. 4th Ed. 1946 Cambridge University Press

.. [Widder] Widder, D. (1941). *The Laplace Transform*. Princeton.

.. [Wikipedia] *Wikipedia, the free encyclopedia*. http://en.wikipedia.org/wiki/Main_Page

.. [WolframFunctions] Wolfram Research, Inc. *The Wolfram Functions Site*. http://functions.wolfram.com/
